package java.awt;

import sun.security.util.SecurityConstants;

public class MouseInfo
{
    private MouseInfo() {
    }
    
    public static PointerInfo getPointerInfo() throws HeadlessException {
        if (GraphicsEnvironment.isHeadless()) {
            throw new HeadlessException();
        }
        SecurityManager securityManager = System.getSecurityManager();
        if (securityManager != null) {
            securityManager.checkPermission(SecurityConstants.AWT.WATCH_MOUSE_PERMISSION);
        }
        Point point = new Point(0, 0);
        int fillPointWithCoords = Toolkit.getDefaultToolkit().getMouseInfoPeer().fillPointWithCoords(point);
        GraphicsDevice[] screenDevices = GraphicsEnvironment.getLocalGraphicsEnvironment().getScreenDevices();
        Object o = null;
        if (areScreenDevicesIndependent(screenDevices)) {
            o = new PointerInfo(screenDevices[fillPointWithCoords], point);
            return o;
        }
        for (int i = 0; i < screenDevices.length; ++i) {
            if (screenDevices[i].getDefaultConfiguration().getBounds().contains(point)) {
                o = new PointerInfo(screenDevices[i], point);
            }
        }
        return o;
    }
    
    private static boolean areScreenDevicesIndependent(GraphicsDevice[] array) {
        int i = 0;
        while (i < array.length) {
            Rectangle bounds = array[i].getDefaultConfiguration().getBounds();
            if (bounds.x != 0 || bounds.y != 0) {
                return false;
            }
            ++i;
        }
        return true;
    }
    
    public static int getNumberOfButtons() throws HeadlessException {
        if (GraphicsEnvironment.isHeadless()) {
            throw new HeadlessException();
        }
        Object desktopProperty = Toolkit.getDefaultToolkit().getDesktopProperty("awt.mouse.numButtons");
        if ((desktopProperty instanceof Integer)) {
            return (int)desktopProperty;
        }
        assert false : "awt.mouse.numButtons is not an integer property";
        return 0;
    }
}
